#!/bin/bash
# packager           : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
# package	     : me tv
# homepage  	     : https://launchpad.net/me-tv/
# dependency         : GTK+ 2.2.x.,libxine, libgnomeui-2.0, libxml2 

softname='me-tv'
softversion='1.3.6'
packageversion='70.1'

arch='i686'
cpu='i686'

prefix=/usr

# log
(

# parameters needed for the build process
buildir=$(pwd)
src="$buildir/$softname-$softversion"
srcpkg="$buildir/$softname-$softversion.tar.gz"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=http://launchpad.net/me-tv/1.3/1.3.6/+download/$softname-$softversion.tar.gz

# prepare the build result directory
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/$prefix/bin
mkdir -p $dest/usr/share/$softname
mkdir -p $dest/usr/share/applications
mkdir -p $dest/usr/share/icons/hicolor/48x48/apps
mkdir -p $dest/usr/doc
mkdir -p $dest/usr/src/$softname-$softversion

# Slack-desc
cat <<EOF > $dest/install/slack-desc 
     |-----handy-ruler------------------------------------------------------|
me-tv: me-tv - a digital television viewer for GNOME
me-tv:
me-tv: Me TV was developed for the modern digital lounge room with a PC for
me-tv: a media centre that is capable of normal PC tasks (web surfing, word
me-tv: processing and watching TV). It is not designed to be a full-blown 
me-tv: media centre, such as MythTV, but will integrate well with 
me-tv: the existing GNOME desktop.
me-tv:
me-tv:
me-tv:
me-tv:
EOF

# check if source is present
if [ -f $softname-$softversion.tar.gz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate $source
fi

# extract the source code
cd $buildir
tar zxvf $srcpkg
cd $src	

# build
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"
    
./configure \
	--program-prefix="" \
	--program-suffix="" \
	--prefix="/usr" \
	--sysconfdir="/etc" \
	--localstatedir="/var" \
	--mandir="/usr/man" \
	--infodir="/usr/info" \
	--without-GNet \
	--disable-schemas-install \
	--with-gconf-source="xml::/etc/gconf/gconf.xml.defaults" \
	--enable-static="no" \
	--enable-shared="yes" \
	--build=$arch-slackware-linux || exit

make
make install DESTDIR=$dest
   
# gconf stuff
export GCONF_CONFIG_SOURCE="xml::$dest/etc/gconf/gconf.xml.defaults"
if [ -d $dest/etc/gconf/schemas ]; then
     install -v -d -m755 $dest/etc/gconf/gconf.xml.defaults
     SCHEMAS=$dest/etc/gconf/schemas
     for schema in $SCHEMAS/*.schemas; do
         gconftool-2 --makefile-install-rule $schema
     done

# reset / Verify correct permissions
     ( cd $dest/etc/gconf ; find . -type d -exec chmod 755 {} \; )
     ( cd $dest/etc/gconf ; find . -type f -exec chmod 644 {} \; )
fi 
   
# make icon
cd $dest/usr/share/icons/hicolor/48x48/apps/
ln -s ../../../../pixmaps/$softname.png  $softname.png

# make .desktop
cat << "EOF" > $dest/usr/share/applications/$softname.desktop
[Desktop Entry]
Encoding=UTF-8
Name=Me-tv
Comment=DVB viewer
Exec=me-tv
Terminal=false
Type=Application
Categories=Application;AudioVideo;
Icon=me-tv
EOF

# add 'default' files
    cd $src
	mkdir -p $dest/usr/doc/$softname-$softversion
    cp -a \
      AUTHORS COPYING INSTALL ChangeLog NEWS README\
      $dest/usr/doc/$softname-$softversion
	
#  strip
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# compress man pages
( cd $dest/$prefix/man
  find . -name "*.?" | xargs gzip -9
)

# ZenBuild
cd $buildir
cp build-$softname.sh $dest/$prefix/src/$softname-$softversion

# set target permissions
chown -R root.root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# real packaging work
cd $dest
makepkg -l y -c n $dest.txz

# computes the md5sum signature for the package
cd $buildir
md5sum $package.txz > $package.md5

# .dep
cd $buildir
echo -e "GConf,ORBit2,atk,cairo,cairomm,cxxlibs|gcc-g++,dbus,dbus-glib,\
expat,fontconfig,freetype,gcc,gconfmm,glib2,glibmm,gnome-screensaver,gtk+2,gtkmm,libX11,\
libXau,libXcomposite,libXcursor,libXdamage,libXdmcp,libXext,libXfixes,\
libXi,libXinerama,libXrandr,libXrender,libpng,libsigc++,libunique,libxcb,\
pango,pangomm,pixman,sqlite,xine-lib,zlib" > $package.dep

# .src
echo http://zenwalk.pinguix.com/user-accounts/bip/EXTRA/xap/metv/source/build-me-tv.sh > $package.src
echo $source >> $package.src

# erase source
rm -rf $src
rm -rf $dest

# log
) 2>&1 | tee "$softname-$softversion-build.log"
